@@ -14,18 +14,6 @@
 # Free Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 # MA  02111-1307  USA
 
-# Copyrights (C)
-# for this R-port:
-#   1999 - 2007, Diethelm Wuertz, GPL
-#   Diethelm Wuertz <wuertz@itp.phys.ethz.ch>
-#   info@rmetrics.org
-#   www.rmetrics.org
-# for the code accessed (or partly included) from other R-ports:
-#   see R's copyright and license files
-# for the code accessed (or partly included) from contributed R-ports
-# and other sources
-#   see Rmetrics's copyright file
-
 
 ################################################################################
 # FUNCTION:               DESCRIPTION:
@@ -34,8 +22,9 @@
 
 
 .modelSeries <-
-function(formula, data, fake = FALSE, lhs = FALSE)
-{   # A function implemented by Diethelm Wuertz
+    function(formula, data, fake = FALSE, lhs = FALSE)
+{   
+    # A function implemented by Diethelm Wuertz
 
     # Arguments:
     #   formula -
@@ -96,3 +85,5 @@ function(formula, data, fake = FALSE, lhs = FALSE)
 
 
 ################################################################################
+
+
